@@ -853,9 +853,9 @@ def get_build_info() -> BuildInfo:
     """
 
     return BuildInfo(
-        version="0.8.1",
-        build="13/12/2022-09:29:06",
-        hash="0x6C0C23BA",
+        version="0.8.2",
+        build="27/01/2023-15:02:35",
+        hash="0x119d2008",
         dirty=False
     )
 
