@@ -7,11 +7,12 @@
 
 # -- include -----------------------------------------------------------------
 
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union, Iterable
 from functools import partial
 from qblox_instruments import InstrumentClass, InstrumentType, TypeHandle
 from qblox_instruments import DeviceInfo, resolve
 from qblox_instruments.ieee488_2 import IpTransport, ClusterDummyTransport
+from qblox_instruments.ieee488_2 import DummyBinnedAcquisitionData, DummyScopeAcquisitionData
 from qblox_instruments.scpi import Cluster as ClusterScpi
 
 import qblox_instruments.native.generic_func as gf
@@ -577,6 +578,55 @@ class Cluster(ClusterScpi):
         _, funcs = self._present_at_init(slot)
         return gf.get_acquisitions(funcs, sequencer)
 
+    # --------------------------------------------------------------------------
+    def set_dummy_binned_acquisition_data(self, slot_idx: int, sequencer: int, acq_index_name: str, data: Iterable[Union[DummyBinnedAcquisitionData, None]]):
+        """
+        Set dummy binned acquisition data for the dummy.
+
+        Parameters
+        ----------
+        slot_idx : int
+            Slot of the hardware you want to set the data to on a cluster.
+        sequencer : int
+            Sequencer.
+        acq_index_name : str
+            Acquisition index name.
+        data : Iterable[Union[DummyBinnedAcquisitionData, None]]
+            Dummy data for the binned acquisition.
+            An iterable of all the bin values.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        self._transport.set_dummy_binned_acquisition_data(slot_idx, sequencer, acq_index_name, data)
+
+    # --------------------------------------------------------------------------
+    def set_dummy_scope_acquisition_data(self, slot_idx: int, sequencer: Union[int, None], data: DummyScopeAcquisitionData):
+        """
+        Set dummy scope acquisition data for the dummy.
+
+        Parameters
+        ----------
+        slot_idx : int
+            Slot of the hardware you want to set the data to on a cluster.
+        sequencer : Union[int, None]
+            Sequencer.
+        data : DummyScopeAcquisitionData
+             Dummy data for the scope acquisition.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        self._transport.set_dummy_scope_acquisition_data(slot_idx, data)
+
     # ------------------------------------------------------------------------
     @gf.copy_docstr(gf.set_sequence)
     def _set_sequence(self, slot: int, sequencer: int, sequence: Union[str, Dict[str, Any]], validation_enable: bool = True) -> None:
