@@ -1811,27 +1811,27 @@ def _get_acq_data_and_convert(
 
     # Retrieve scope data
     scope_data = init_read_func()
-    acquisition_dict["scope"]["path0"]["data"] = list(struct.unpack("i" * int(len(scope_data) / 4), scope_data))
-    acquisition_dict["scope"]["path0"]["out-of-range"] = struct.unpack("?", funcs._read_bin("", False))[0]
-    acquisition_dict["scope"]["path0"]["avg_cnt"] = struct.unpack("I", funcs._read_bin("", False))[0]
+    path0_scope_raw = numpy.array(struct.unpack("i" * int(len(scope_data) / 4), scope_data))
+    path0_oor = struct.unpack("?", funcs._read_bin("", False))[0]
+    path0_avg_cnt = struct.unpack("I", funcs._read_bin("", False))[0]
     scope_data = funcs._read_bin("", False)
-    acquisition_dict["scope"]["path1"]["data"] = list(struct.unpack("i" * int(len(scope_data) / 4), scope_data))
-    acquisition_dict["scope"]["path1"]["out-of-range"] = struct.unpack("?", funcs._read_bin("", False))[0]
-    acquisition_dict["scope"]["path1"]["avg_cnt"] = struct.unpack("I", funcs._read_bin("", False))[0]
+    path1_scope_raw = numpy.array(struct.unpack("i" * int(len(scope_data) / 4), scope_data))
+    path1_oor = struct.unpack("?", funcs._read_bin("", False))[0]
+    path1_avg_cnt = struct.unpack("I", funcs._read_bin("", False))[0]
 
     # Normalize scope data
-    avg_cnt = acquisition_dict["scope"]["path0"]["avg_cnt"]
-    acquisition_dict["scope"]["path0"]["data"] = [
-        val / max_sample_value if avg_cnt == 0 else val / max_sample_value / avg_cnt
-        for val in acquisition_dict["scope"]["path0"]["data"]
-    ]
-    avg_cnt = acquisition_dict["scope"]["path1"]["avg_cnt"]
-    acquisition_dict["scope"]["path1"]["data"] = [
-        val / max_sample_value if avg_cnt == 0 else val / max_sample_value / avg_cnt
-        for val in acquisition_dict["scope"]["path1"]["data"]
-    ]
+    path0_scope = numpy.where(
+        path0_avg_cnt > 0,
+        path0_scope_raw / max_sample_value / path0_avg_cnt,
+        path0_scope_raw / max_sample_value
+    )
+    path1_scope = numpy.where(
+        path1_avg_cnt > 0,
+        path1_scope_raw / max_sample_value / path1_avg_cnt,
+        path1_scope_raw / max_sample_value
+    )
 
-    # Convert to long values
+    # Retrieve bin data and convert to long values
     bins = funcs._read_bin("", flush_line_end)
     bin_data = numpy.frombuffer(bins, dtype=numpy.int64).reshape(-1,4)
     valid = bin_data[:,0].astype(bool)
@@ -1844,6 +1844,7 @@ def _get_acq_data_and_convert(
     thres_raw = thres_avg_cnt_raw & 0xFFFFFFFF
     avg_cnt = thres_avg_cnt_raw >> 32
 
+    # Normalize bin data
     path0_raw = numpy.where(avg_cnt > 0, path0_raw / avg_cnt, path0_raw)
     path1_raw = numpy.where(avg_cnt > 0, path1_raw / avg_cnt, path1_raw)
     thres_raw = numpy.where(avg_cnt > 0, thres_raw / avg_cnt, thres_raw)
@@ -1853,6 +1854,15 @@ def _get_acq_data_and_convert(
     thres_data = numpy.where(valid, thres_raw, numpy.nan)
     avg_cnt_data = numpy.where(valid, avg_cnt, numpy.nan)
 
+    # Set final results
+    acquisition_dict["scope"]["path0"]["data"] = path0_scope.tolist()
+    acquisition_dict["scope"]["path0"]["out-of-range"] = path0_oor
+    acquisition_dict["scope"]["path0"]["avg_cnt"] = path0_avg_cnt
+
+    acquisition_dict["scope"]["path1"]["data"] = path1_scope.tolist()
+    acquisition_dict["scope"]["path1"]["out-of-range"] = path1_oor
+    acquisition_dict["scope"]["path1"]["avg_cnt"] = path1_avg_cnt
+
     acquisition_dict["bins"]["integration"]["path0"] = path0_data.tolist()
     acquisition_dict["bins"]["integration"]["path1"] = path1_data.tolist()
     acquisition_dict["bins"]["threshold"] = thres_data.tolist()
