@@ -7,7 +7,7 @@
 
 # -- include -----------------------------------------------------------------
 
-from typing import List, Union
+from typing import List, Union, NoReturn
 from functools import partial
 from qcodes import validators as vals
 from qcodes import Instrument, InstrumentChannel
@@ -138,9 +138,11 @@ class Sequencer(InstrumentChannel):
             "nco_freq",
             label="Sequencer NCO frequency",
             docstring="Sets/gets sequencer NCO frequency in Hz with a "
-                      "resolution of 0.25 Hz.",
+                    "resolution of 0.25 Hz. Be aware that the outputs "
+                    "have low-pass filters with a cut-off frequency of "
+                    "{} MHz".format("300" if self.parent.is_rf_type else "350"),
             unit="Hz",
-            vals=vals.Numbers(-300e6, 300e6),
+            vals=vals.Numbers(-500e6, 500e6),
             set_parser=float,
             get_parser=float,
             set_cmd=partial(
@@ -172,6 +174,48 @@ class Sequencer(InstrumentChannel):
             ),
         )
 
+        self.add_parameter(
+            "nco_prop_delay_comp",
+            label="Sequencer NCO propagation delay compensation",
+            docstring="Sets/gets a delay that compensates the NCO phase "
+                        "to the input path with respect to the instrument's "
+                        "combined output and input propagation delay. This "
+                        "delay is applied on top of a default delay of 146 ns.",
+            unit="ns",
+            vals=vals.Numbers(-50, 50),
+            set_parser=int,
+            get_parser=int,
+            set_cmd=partial(
+                self._set_sequencer_config_val,
+                "nco_prop_delay_comp"
+            ),
+            get_cmd=partial(
+                self._get_sequencer_config_val,
+                "nco_prop_delay_comp"
+            ),
+        )
+
+        self.add_parameter(
+            "nco_prop_delay_comp_en",
+            label="Sequencer NCO propagation delay compensation enable",
+            docstring="Sets/gets the enable for a delay that compensates "
+                        "the NCO phase to the input path with respect to the "
+                        "instrument's combined output and input propagation "
+                        "delay. This delays the frequency update as well.",
+            unit="ns",
+            vals=vals.Bool(),
+            set_parser=bool,
+            get_parser=bool,
+            set_cmd=partial(
+                self._set_sequencer_config_val,
+                "nco_prop_delay_comp_en"
+            ),
+            get_cmd=partial(
+                self._get_sequencer_config_val,
+                "nco_prop_delay_comp_en"
+            ),
+        )
+
         self.add_parameter(
             "marker_ovr_en",
             label="Sequencer marker override enable",
@@ -218,6 +262,8 @@ class Sequencer(InstrumentChannel):
                       "compatible dictionary.",
             vals=vals.MultiType(vals.Strings(), vals.Dict()),
             set_cmd=self._set_sequence,
+            get_cmd=Sequencer._get_sequence_raise,
+            snapshot_get=False,
         )
 
         # -- AWG settings (All modules) --------------------------------------
@@ -546,6 +592,67 @@ class Sequencer(InstrumentChannel):
                 ),
             )
 
+            if not self.parent.is_rf_type:
+                self.add_parameter(
+                        "ttl_acq_auto_bin_incr_en",
+                        label="TTL trigger acquisition automatic bin increase.",
+                        docstring="Sets/gets whether the bin index is automatically "
+                                  "incremented when acquiring multiple triggers. "
+                                  "Disabling the TTL trigger acquisition path "
+                                  "resets the bin index.",
+                        unit="",
+                        vals= vals.Bool(),
+                        set_parser=bool,
+                        get_parser=bool,
+                        set_cmd=partial(
+                            self._set_sequencer_config_val,
+                            "ttl_auto_bin_incr_en"
+                        ),
+                        get_cmd=partial(
+                            self._get_sequencer_config_val,
+                            "ttl_auto_bin_incr_en"
+                        ),
+                    )
+
+                self.add_parameter(
+                    "ttl_acq_threshold",
+                    label="TTL trigger acquisition threshold",
+                    docstring="Sets/gets the threshold value with which to compare "
+                              "the input ADC values of the selected input path.",
+                    unit="",
+                    vals= vals.Numbers(-1.0,1.0),
+                    set_parser=float,
+                    get_parser=float,
+                    set_cmd=partial(
+                        self._set_sequencer_config_val,
+                        "ttl_threshold"
+                    ),
+                    get_cmd=partial(
+                        self._get_sequencer_config_val,
+                        "ttl_threshold"
+                    ),
+                )
+
+                self.add_parameter(
+                    "ttl_acq_input_select",
+                    label="TTL trigger acquisition input",
+                    docstring="Sets/gets the input used to compare against "
+                              "the threshold value in the TTL trigger acquisition "
+                              "path.",
+                    unit="",
+                    vals= vals.Numbers(0,1),
+                    set_parser=int,
+                    get_parser=int,
+                    set_cmd=partial(
+                        self._set_sequencer_config_val,
+                        "ttl_in"
+                    ),
+                    get_cmd=partial(
+                        self._get_sequencer_config_val,
+                        "ttl_in"
+                    ),
+                )
+
     # ------------------------------------------------------------------------
     @property
     def seq_idx(self) -> int:
@@ -600,6 +707,10 @@ class Sequencer(InstrumentChannel):
         attr_names.append("stop_sequencer")
         attr_names.append("get_sequencer_state")
 
+        # Dummy acquisition data attributes
+        attr_names.append("set_dummy_binned_acquisition_data")
+        attr_names.append("set_dummy_scope_acquisition_data")
+
         # Waveform, weight and acquisition attributes
         for component in ["waveform", "weight", "acquisition"]:
             attr_names.append("_add_{}s".format(component))
@@ -667,3 +778,14 @@ class Sequencer(InstrumentChannel):
 
         for param in self.parameters.values():
             param.cache.invalidate()
+
+    # ------------------------------------------------------------------------
+    @staticmethod
+    def _get_sequence_raise() -> NoReturn:
+        raise RuntimeError(
+            "The `sequence` parameter cannot be queried from the instrument. "
+            "Use `sequencer.sequence.cache()` instead. "
+            "If this exception was raised by `sequencer.sequence.cache()`, "
+            "then the cache was invalid and the instrument state is unknown "
+            "(after startup or reset)."
+        )
